is_python_package

Function is_python_package 

pub fn is_python_package(path: &Path) -> Result<bool>
determines whether given path is a Python package i.e. a directory with a __init__.py file see https://docs.python.org/3/tutorial/modules.html#packages

Errors

returns an error if there is any fs error